@@ -3,13 +3,13 @@
 # Copyright 2021 Observational Health Data Sciences and Informatics
 #
 # This file is part of DatabaseConnector
-# 
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -32,15 +32,15 @@ NULL
 #'
 #' @title
 #' How to download and use JDBC drivers for the various data platforms.
-#' 
-#' @description 
+#'
+#' @description
 #' Below are instructions for downloading JDBC drivers for the various data platforms. Once downloaded
 #' use the \code{pathToDriver} argument in the \code{\link{connect}} or \code{\link{createConnectionDetails}}
-#' functions to point to the driver. Alternatively, you can set the 'DATABASECONNECTOR_JAR_FOLDER' environmental 
+#' functions to point to the driver. Alternatively, you can set the 'DATABASECONNECTOR_JAR_FOLDER' environmental
 #' variable, for example in your .Renviron file (recommended).
-#' 
+#'
 #' @section
-#' SQL Server, Oracle, PostgreSQL, PDW, RedShift: Use the \code{\link{downloadJdbcDrivers}} function to download these drivers
+#' SQL Server, Oracle, PostgreSQL, PDW, Spark, RedShift: Use the \code{\link{downloadJdbcDrivers}} function to download these drivers
 #' from the OHDSI GitHub pages.
 #'
 #' @section
@@ -56,17 +56,18 @@ NULL
 #' Impala: Go to
 #' \href{https://www.cloudera.com/downloads/connectors/impala/jdbc/2-5-5.html}{Cloudera's site}, pick
 #' your OS version, and click "GET IT NOW!'. Register, and you should be able to download the driver.
-#' 
+#'
 #' @section
 #' SQLite: For SQLite we actually don't use a JDBC driver. Instead, we use the RSQLite package, which can be installed
 #' using \code{install.packages("RSQLite")}.
-#' 
+#'
 NULL
 
 # Borrowed from devtools: https://github.com/hadley/devtools/blob/ba7a5a4abd8258c52cb156e7b26bb4bf47a79f0b/R/utils.r#L44
 is_installed <- function(pkg, version = 0) {
-  installed_version <- tryCatch(utils::packageVersion(pkg), 
-                                error = function(e) NA)
+  installed_version <- tryCatch(utils::packageVersion(pkg),
+    error = function(e) NA
+  )
   !is.na(installed_version) && installed_version >= version
 }
 
